@@ -7,20 +7,26 @@ knitr::opts_chunk$set(
 library(uchardet)
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  system.file("examples", path, package = "uchardet")
+#  dir(system.file("examples", package = "uchardet"), recursive = TRUE, full.names = TRUE)
 
 ## -----------------------------------------------------------------------------
 detect_str_enc("Hello, useR!")
 
 ## -----------------------------------------------------------------------------
-# get file path
-file <- system.file("examples", "zh/big5.txt", package = "uchardet")
-# create the file connection with the encoding
-con <- file(file, encoding = "BIG-5")
+read_char <- function(path, enc) {
+  # get file path
+  file <- system.file("examples", path, package = "uchardet")
+  # create the file connection with the encoding
+  con <- file(file, encoding = enc)
+  # close connection on exit
+  on.exit(close(con))
+  # read file content
+  paste(readLines(con, warn = FALSE), collapse = "\n")
+}
+
+## -----------------------------------------------------------------------------
 # read file into the working env
-zh_utf8 <- paste(readLines(con, warn = FALSE), collapse = "\n")
-# close connection
-close(con)
+zh_utf8 <- read_char("zh/big5.txt", "BIG-5")
 # print content
 print(zh_utf8)
 # check the encoding of the created object
@@ -43,7 +49,10 @@ detect_str_enc(c(zh_utf8, zh_big5, zh_gb))
 Encoding(c(zh_utf8, zh_big5, zh_gb))
 
 ## -----------------------------------------------------------------------------
-read_bin <- function(path) {
+detect_raw_enc(charToRaw("Hello, useR!"))
+
+## -----------------------------------------------------------------------------
+read_raw <- function(path) {
   # get file path
   file <- system.file("examples", path, package = "uchardet")
   # read file to raw vector
@@ -51,16 +60,13 @@ read_bin <- function(path) {
 }
 
 # print first 5 bytes
-read_bin("de/iso-8859-1.txt")[1:5]
+read_raw("de/iso-8859-1.txt")[1:5]
 
 ## -----------------------------------------------------------------------------
-detect_raw_enc(charToRaw("Hello, useR!"))
-
-## -----------------------------------------------------------------------------
-detect_raw_enc(read_bin("de/iso-8859-1.txt"))
-detect_raw_enc(read_bin("de/windows-1252.txt"))
-detect_raw_enc(read_bin("fr/utf-16.be"))
-detect_raw_enc(read_bin("zh/big5.txt"))
+detect_raw_enc(read_raw("de/iso-8859-1.txt"))
+detect_raw_enc(read_raw("de/windows-1252.txt"))
+detect_raw_enc(read_raw("fr/utf-16.be"))
+detect_raw_enc(read_raw("zh/big5.txt"))
 
 ## ----warning = FALSE----------------------------------------------------------
 # paths to examples files
